<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.ApplicationModel.VoiceCommands

Windows Runtime (WinRT) APIs for for the `Windows.ApplicationModel.VoiceCommands` namespace.

This package provides the `winrt.windows.applicationmodel.voicecommands` module.
